@@ -22,6 +22,7 @@
 
 #include "../include/sane/sanei_debug.h"
 
+#include <stdlib.h>
 
 static inline unsigned
 mm2scanner_units (unsigned mm)
@@ -227,8 +228,8 @@ static SANE_String_Const lamp_list[] = {
 };
 static SANE_String_Const dfeed_sence_list[] = {
   SANE_I18N ("Normal"),
-  SANE_I18N ("High sensivity"),
-  SANE_I18N ("Low sensivity"),
+  SANE_I18N ("High sensitivity"),
+  SANE_I18N ("Low sensitivity"),
   NULL
 };
 
@@ -355,7 +356,7 @@ kvs40xx_init_options (struct scanner *s)
   o->unit = SANE_UNIT_NONE;
   s->val[DUPLEX].w = SANE_FALSE;
 
-  /*FIXME 
+  /*FIXME
      if (!s->support_info.support_duplex)
      o->cap |= SANE_CAP_INACTIVE;
    */
@@ -392,8 +393,8 @@ kvs40xx_init_options (struct scanner *s)
   o->title = SANE_I18N ("Length control mode");
   o->desc =
     SANE_I18N
-    ("Length Control Mode is a mode that the scanner reads up to the shorter length of actual"
-     " paper or logical document length.");
+    ("Length Control Mode causes the scanner to read the shorter of either the length of the actual"
+     " paper or logical document length");
   o->type = SANE_TYPE_BOOL;
   o->unit = SANE_UNIT_NONE;
   s->val[LENGTHCTL].w = SANE_FALSE;
@@ -714,7 +715,7 @@ kvs40xx_init_options (struct scanner *s)
   o->title = SANE_I18N ("JPEG compression");
   o->desc =
     SANE_I18N
-    ("JPEG compression (yours application must be able to uncompress)");
+    ("JPEG compression (your application must be able to uncompress)");
   o->type = SANE_TYPE_BOOL;
   o->unit = SANE_UNIT_NONE;
 
@@ -804,8 +805,8 @@ kvs40xx_init_options (struct scanner *s)
 
   o = &s->opt[STOP_SKEW];
   o->name = "stop-skew";
-  o->title = SANE_I18N ("Stop scanner when a paper have been skewed");
-  o->desc = SANE_I18N ("Scanner will be stop  when a paper have been skewed");
+  o->title = SANE_I18N ("Stop scanner if a sheet is skewed");
+  o->desc = SANE_I18N ("Scanner will stop if a sheet is skewed");
   o->type = SANE_TYPE_BOOL;
   o->unit = SANE_UNIT_NONE;
   s->val[STOP_SKEW].w = SANE_FALSE;
@@ -813,7 +814,7 @@ kvs40xx_init_options (struct scanner *s)
   o = &s->opt[CROP];
   o->name = "crop";
   o->title = SANE_I18N ("Crop actual image area");
-  o->desc = SANE_I18N ("Scanner automatically detect image area and crop it");
+  o->desc = SANE_I18N ("Scanner will automatically detect image area and crop to it");
   o->type = SANE_TYPE_BOOL;
   o->unit = SANE_UNIT_NONE;
   s->val[CROP].w = SANE_FALSE;
@@ -823,7 +824,7 @@ kvs40xx_init_options (struct scanner *s)
   o = &s->opt[MIRROR];
   o->name = "mirror";
   o->title = SANE_I18N ("Mirror image");
-  o->desc = SANE_I18N ("It is right and left reversing");
+  o->desc = SANE_I18N ("Left/right mirror image");
   o->type = SANE_TYPE_BOOL;
   o->unit = SANE_UNIT_NONE;
   s->val[MIRROR].w = SANE_FALSE;
@@ -1271,41 +1272,45 @@ kvs40xx_init_window (struct scanner *s, struct window *wnd, int wnd_id)
 {
   int paper = str_index (paper_list, s->val[PAPER_SIZE].s), i;
   memset (wnd, 0, sizeof (struct window));
-  *(u16 *) wnd->window_descriptor_block_length = cpu2be16 (66);
+  copy16 (wnd->window_descriptor_block_length, cpu2be16 (66));
 
   wnd->window_identifier = wnd_id;
-  *(u16 *) wnd->x_resolution = cpu2be16 (s->val[RESOLUTION].w);
-  *(u16 *) wnd->y_resolution = cpu2be16 (s->val[RESOLUTION].w);
+  copy16 (wnd->x_resolution, cpu2be16 (s->val[RESOLUTION].w));
+  copy16 (wnd->y_resolution, cpu2be16 (s->val[RESOLUTION].w));
   if (!paper)
     {
-      *(u32 *) wnd->upper_left_x =
-	cpu2be32 (mm2scanner_units (s->val[TL_X].w));
-      *(u32 *) wnd->upper_left_y =
-	cpu2be32 (mm2scanner_units (s->val[TL_Y].w));
-      *(u32 *) wnd->document_width =
-	cpu2be32 (mm2scanner_units (s->val[BR_X].w));
-      *(u32 *) wnd->width =
-	cpu2be32 (mm2scanner_units (s->val[BR_X].w - s->val[TL_X].w));
-      *(u32 *) wnd->document_length = cpu2be32 (mm2scanner_units
-						(s->val[BR_Y].w));
-      *(u32 *) wnd->length =
-	cpu2be32 (mm2scanner_units (s->val[BR_Y].w - s->val[TL_Y].w));
+      copy32 (wnd->upper_left_x,
+              cpu2be32 (mm2scanner_units (s->val[TL_X].w)));
+      copy32 (wnd->upper_left_y,
+              cpu2be32 (mm2scanner_units (s->val[TL_Y].w)));
+      copy32 (wnd->document_width,
+              cpu2be32 (mm2scanner_units (s->val[BR_X].w)));
+      copy32 (wnd->width,
+              cpu2be32 (mm2scanner_units (s->val[BR_X].w - s->val[TL_X].w)));
+      copy32 (wnd->document_length, cpu2be32 (mm2scanner_units
+                                              (s->val[BR_Y].w)));
+      copy32 (wnd->length,
+              cpu2be32 (mm2scanner_units (s->val[BR_Y].w - s->val[TL_Y].w)));
     }
   else
     {
       u32 w = cpu2be32 (mm2scanner_units (paper_sizes[paper].width));
       u32 h = cpu2be32 (mm2scanner_units (paper_sizes[paper].height));
-      *(u32 *) wnd->upper_left_x = cpu2be32 (mm2scanner_units (0));
-      *(u32 *) wnd->upper_left_y = cpu2be32 (mm2scanner_units (0));
+      copy32 (wnd->upper_left_x, cpu2be32 (mm2scanner_units (0)));
+      copy32 (wnd->upper_left_y, cpu2be32 (mm2scanner_units (0)));
       if (!s->val[LANDSCAPE].b)
 	{
-	  *(u32 *) wnd->document_width = *(u32 *) wnd->width = w;
-	  *(u32 *) wnd->document_length = *(u32 *) wnd->length = h;
+	  copy32 (wnd->width, w);
+	  copy32 (wnd->length, h);
+	  copy32 (wnd->document_width, w);
+	  copy32 (wnd->document_length, h);
 	}
       else
 	{
-	  *(u32 *) wnd->document_width = *(u32 *) wnd->width = h;
-	  *(u32 *) wnd->document_length = *(u32 *) wnd->length = w;
+	  copy32 (wnd->width, h);
+	  copy32 (wnd->length, w);
+	  copy32 (wnd->document_width, h);
+	  copy32 (wnd->document_length, w);
 	}
     }
   wnd->brightness = s->val[BRIGHTNESS].w;
@@ -1314,11 +1319,11 @@ kvs40xx_init_window (struct scanner *s, struct window *wnd, int wnd_id)
   wnd->image_composition = mode_val[str_index (mode_list, s->val[MODE].s)];
   wnd->bit_per_pixel = bps_val[str_index (mode_list, s->val[MODE].s)];
 
-  *(u16 *) wnd->halftone_pattern =
-    cpu2be16 (str_index (halftone_pattern, s->val[HALFTONE_PATTERN].s));
+  copy16 (wnd->halftone_pattern,
+          cpu2be16 (str_index (halftone_pattern, s->val[HALFTONE_PATTERN].s)));
 
   wnd->rif_padding = s->val[INVERSE].b << 7;
-  *(u16 *) wnd->bit_ordering = cpu2be16 (BIT_ORDERING);
+  copy16 (wnd->bit_ordering, cpu2be16 (BIT_ORDERING));
   wnd->compression_type = s->val[COMPRESSION].b ? 0x81 : 0;
   wnd->compression_argument = s->val[COMPRESSION_PAR].w;
 
