@@ -863,7 +863,7 @@ snapscan (void)
 
 
 /**
- * create the test suite for sanei config related tests 
+ * create the test suite for sanei config related tests
  */
 static void
 sanei_config_suite (void)
@@ -890,11 +890,14 @@ sanei_config_suite (void)
 }
 
 /**
- * main function to run the test suites 
+ * main function to run the test suites
  */
 int
 main (void)
 {
+  /* set up config dir for local conf files */
+  putenv("SANE_CONFIG_DIR=.:/");
+
   /* run suites */
   sanei_config_suite ();
 
